@@ -20,7 +20,7 @@ class Context:
         self.__args = args
         self.__postdata = postdata
         self.__response = response
-        self.__session = session
+        self.__session = {} if session is None else session
         self.__aws_event = aws_event
         self.__aws_context = aws_context
         self.__log = log
@@ -199,7 +199,7 @@ class Context:
             payload = [payload]
         messages = []
         if user is None:
-            user = self.session.get("email_address") or "EnqueueTasks"
+            user = self.session().get("email_address") or "EnqueueTasks"
         for item in payload:
             message = {"action": action, "payload": item}
             id = str(uuid.uuid4()).split("-")[0]
