@@ -348,10 +348,16 @@ class Engine:
                 f"\n\nSQL Query:\n{self._format_sql_with_params(sql, parameters)}"
             )
 
+        # Format SQL for logging
+        formatted_sql_info = ""
+        if sql:
+            formatted_sql_info = f" sql={self._format_sql_with_params(sql, parameters)}"
+
         logger.warning(
-            "Database error caught. Attempting to transform: code=%s message=%s",
+            "Database error caught. Attempting to transform: code=%s message=%s%s",
             error_code,
             error_message,
+            formatted_sql_info,
         )
 
         # Direct error code mapping
