@@ -1,7 +1,7 @@
 import re
 import hashlib
 import sqlparse
-from psycopg2 import sql
+from psycopg2 import sql as psycopg2_sql
 
 from velocity.db import exceptions
 
@@ -985,7 +985,7 @@ class SQL:
             columns = TableHelper.quote(columns)
         sql = ["DROP"]
         sql.append("INDEX IF EXISTS")
-        tablename = TableHelper.quote(table)
+        _tablename = TableHelper.quote(table)
         if not name:
             name = re.sub(
                 r"\([^)]*\)",
@@ -1155,9 +1155,9 @@ class SQL:
     @classmethod
     def missing(cls, tx, table, list, column="SYS_ID", where=None):
         sql = [
-            f"SELECT * FROM",
+            "SELECT * FROM",
             f"UNNEST('{{{','.join([str(x) for x in list])}}}'::int[]) id",
-            f"EXCEPT ALL",
+            "EXCEPT ALL",
             f"SELECT {column} FROM {table}",
         ]
         vals = []
