@@ -30,7 +30,7 @@ def make_where(where, sql, vals, is_join=False):
             if is_join:
                 if "." not in key:
                     key = "A." + key
-            if val == None:
+            if val is None:
                 if "!" in key:
                     key = key.replace("!", "")
                     sql.append("{} is not NULL".format(quote(key.lower())))
@@ -394,7 +394,7 @@ class SQL:
         cls, table, columns, key_to_table, key_to_columns, name=None, schema=None
     ):
         if "." not in table and schema:
-            if schema == None:
+            if schema is None:
                 schema = cls.default_schema
             table = "{}.{}".format(schema, table)
         if isinstance(key_to_columns, str):
@@ -873,7 +873,7 @@ class SQL:
             for key in sorted(where.keys()):
                 if join:
                     sql.append(join)
-                if where[key] == None:
+                if where[key] is None:
                     sql.append("{} is NULL".format(quote(key.lower())))
                 else:
                     sql.append("{} = %s".format(quote(key.lower())))
